@@ -4,7 +4,7 @@ use rayon::prelude::*;
 impl DiagonalMatrix<f64> {
     /// # Pow integer
     /// for diagonal matrix
-    pub fn dipowi(self, exp: i32) -> Self {
+    pub fn powi(self, exp: i32) -> Self {
         let mut slf = self;
         slf.d.par_iter_mut().for_each(|di| *di = di.powi(exp));
 
@@ -15,7 +15,7 @@ impl DiagonalMatrix<f64> {
 impl DiagonalMatrix<c64> {
     /// # Pow integer
     /// for diagonal matrix
-    pub fn dipowi(self, exp: i32) -> Self {
+    pub fn powi(self, exp: i32) -> Self {
         let mut slf = self;
         slf.d.par_iter_mut().for_each(|di| *di = di.powi(exp));
 
@@ -29,12 +29,12 @@ mod tests {
     #[test]
     fn it_works() {
         let a = DiagonalMatrix::<f64>::identity(2);
-        let a_inv = a.clone().diinv();
+        let a_inv = a.clone().powi(-1);
 
         assert_eq!(a[0], a_inv[0]);
 
         let a = DiagonalMatrix::<c64>::identity(2);
-        let a_inv = a.clone().diinv();
+        let a_inv = a.clone().powi(-1);
 
         assert_eq!(a[0], a_inv[0]);
     }
